# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.course_simple import CourseSimple

class TestCourseSimple(unittest.TestCase):
    """CourseSimple unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CourseSimple:
        """Test CourseSimple
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CourseSimple`
        """
        model = CourseSimple()
        if include_optional:
            return CourseSimple(
                title = '',
                image_id = '',
                description = '',
                url = '',
                payload = '',
                module_view_type = 'list',
                payment_type = 'paid',
                course_access_type = 'subscription',
                number_days_access = 56,
                is_active = True,
                is_secret = True,
                is_archived = True,
                is_displayed_in_app = True,
                is_offline_downloadable = True,
                available_at = 56,
                launch_date_enabled = True,
                launch_date = 56,
                id = 56,
                portal_id = 56,
                order = 56,
                category = '',
                category_id = 56,
                sales_page_landing_id = 56,
                permalink = '',
                enable_double_optin = True,
                one_more_landing_id = 56,
                one_more_step_link = '',
                one_more_step_landing_id = 56,
                created_at_epoch = 56
            )
        else:
            return CourseSimple(
                title = '',
                is_active = True,
                is_secret = True,
                is_archived = True,
                is_displayed_in_app = True,
                is_offline_downloadable = True,
                id = 56,
                portal_id = 56,
                order = 56,
                created_at_epoch = 56,
        )
        """

    def testCourseSimple(self):
        """Test CourseSimple"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
