# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from public_api_server_connector_v2.models.button_position import ButtonPosition
from public_api_server_connector_v2.models.button_size import ButtonSize
from public_api_server_connector_v2.models.button_target import ButtonTarget
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class Content(BaseModel):
    """
    Content
    """ # noqa: E501
    link: Optional[StrictStr] = Field(default=None, description="Link to the content, e.g. YouTube video link")
    file_id: Optional[StrictStr] = Field(default=None, description="File id from the file storage service")
    audio_id: Optional[StrictStr] = Field(default=None, description="Audio id for audio content blocks")
    payload: Optional[StrictStr] = Field(default=None, description="Raw content payload, e.g. HTML or text content")
    btn_url: Optional[StrictStr] = Field(default=None, description="Button URL, has to be set if the block is a button")
    btn_font: Optional[StrictStr] = Field(default=None, description="Button font, if not set, default font (Public Sans) is used")
    btn_size: Optional[ButtonSize] = Field(default=None, description="Button size, if not set, default (medium) size is used")
    btn_text: Optional[StrictStr] = Field(default=None, description="Button text, has to be set if the block is a button")
    btn_color: Optional[StrictStr] = Field(default=None, description="Button color in hex format, default (#415BF5) is used if not set")
    btn_target: Optional[ButtonTarget] = Field(default=None, description="Button target url, default (_blank) is used if not set")
    btn_position: Optional[ButtonPosition] = Field(default=None, description="Button position, default (center) is used if not set")
    btn_text_color: Optional[StrictStr] = Field(default=None, description="Button text color, default (#FFFFFF) is used if not set")
    pdf_id: Optional[StrictStr] = Field(default=None, description="PDF file id from the file storage service, file is served read-only")
    __properties: ClassVar[List[str]] = ["link", "file_id", "audio_id", "payload", "btn_url", "btn_font", "btn_size", "btn_text", "btn_color", "btn_target", "btn_position", "btn_text_color", "pdf_id"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Content from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Content from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "link": obj.get("link"),
            "file_id": obj.get("file_id"),
            "audio_id": obj.get("audio_id"),
            "payload": obj.get("payload"),
            "btn_url": obj.get("btn_url"),
            "btn_font": obj.get("btn_font"),
            "btn_size": obj.get("btn_size"),
            "btn_text": obj.get("btn_text"),
            "btn_color": obj.get("btn_color"),
            "btn_target": obj.get("btn_target"),
            "btn_position": obj.get("btn_position"),
            "btn_text_color": obj.get("btn_text_color"),
            "pdf_id": obj.get("pdf_id")
        })
        return _obj


