# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.course import Course

class TestCourse(unittest.TestCase):
    """Course unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Course:
        """Test Course
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Course`
        """
        model = Course()
        if include_optional:
            return Course(
                title = '',
                image_id = '',
                description = '',
                url = '',
                payload = '',
                module_view_type = 'list',
                payment_type = 'paid',
                course_access_type = 'subscription',
                number_days_access = 56,
                is_active = True,
                is_secret = True,
                is_archived = True,
                is_displayed_in_app = True,
                is_offline_downloadable = True,
                available_at = 56,
                launch_date_enabled = True,
                launch_date = 56,
                id = 56,
                portal_id = 56,
                order = 56,
                category = '',
                category_id = 56,
                sales_page_landing_id = 56,
                permalink = '',
                enable_double_optin = True,
                one_more_landing_id = 56,
                one_more_step_link = '',
                one_more_step_landing_id = 56,
                created_at_epoch = 56,
                modules = [
                    public_api_server_connector_v2.models.course_module.CourseModule(
                        mandatory = True, 
                        is_published = True, 
                        is_active = True, 
                        title = '', 
                        public_description = '', 
                        short_description = '', 
                        image_id = '', 
                        available_at = 56, 
                        id = 56, 
                        course_id = 56, 
                        order = 56, 
                        submodules = [
                            public_api_server_connector_v2.models.course_submodule.CourseSubmodule(
                                order = 56, 
                                title = '', 
                                is_published = True, 
                                id = 56, 
                                module_id = 56, 
                                created_at = 56, )
                            ], 
                        lessons = [
                            public_api_server_connector_v2.models.module_lesson.ModuleLesson(
                                submodule_id = 56, 
                                thread_id = 56, 
                                lesson_type = null, 
                                image_id = '', 
                                title = '', 
                                payload = '', 
                                is_active = True, 
                                is_published = True, 
                                mandatory = True, 
                                id = 56, 
                                module_id = 56, 
                                order = 56, 
                                public_key = '', 
                                content_blocks = [
                                    public_api_server_connector_v2.models.content_block.ContentBlock(
                                        block_type = null, 
                                        order = 56, 
                                        is_expanded = True, 
                                        content = null, 
                                        id = 56, 
                                        lesson_id = 56, 
                                        created_at = 56, )
                                    ], 
                                attached_files = [
                                    public_api_server_connector_v2.models.attached_file.AttachedFile(
                                        order = 56, 
                                        file_id = 56, 
                                        id = 56, 
                                        lesson_id = 56, 
                                        created_at = 56, )
                                    ], )
                            ], )
                    ],
                content_blocks = [
                    public_api_server_connector_v2.models.course_content_block.CourseContentBlock(
                        block_type = 'text', 
                        order = 56, 
                        is_expanded = True, 
                        content = public_api_server_connector_v2.models.content.Content(
                            link = '', 
                            file_id = '', 
                            audio_id = '', 
                            payload = '', 
                            btn_url = '', 
                            btn_font = '', 
                            btn_size = null, 
                            btn_text = '', 
                            btn_color = '', 
                            btn_target = null, 
                            btn_position = null, 
                            btn_text_color = '', 
                            pdf_id = '', ), 
                        id = 56, 
                        course_id = 56, 
                        created_at = 56, )
                    ]
            )
        else:
            return Course(
                title = '',
                is_active = True,
                is_secret = True,
                is_archived = True,
                is_displayed_in_app = True,
                is_offline_downloadable = True,
                id = 56,
                portal_id = 56,
                order = 56,
                created_at_epoch = 56,
                modules = [
                    public_api_server_connector_v2.models.course_module.CourseModule(
                        mandatory = True, 
                        is_published = True, 
                        is_active = True, 
                        title = '', 
                        public_description = '', 
                        short_description = '', 
                        image_id = '', 
                        available_at = 56, 
                        id = 56, 
                        course_id = 56, 
                        order = 56, 
                        submodules = [
                            public_api_server_connector_v2.models.course_submodule.CourseSubmodule(
                                order = 56, 
                                title = '', 
                                is_published = True, 
                                id = 56, 
                                module_id = 56, 
                                created_at = 56, )
                            ], 
                        lessons = [
                            public_api_server_connector_v2.models.module_lesson.ModuleLesson(
                                submodule_id = 56, 
                                thread_id = 56, 
                                lesson_type = null, 
                                image_id = '', 
                                title = '', 
                                payload = '', 
                                is_active = True, 
                                is_published = True, 
                                mandatory = True, 
                                id = 56, 
                                module_id = 56, 
                                order = 56, 
                                public_key = '', 
                                content_blocks = [
                                    public_api_server_connector_v2.models.content_block.ContentBlock(
                                        block_type = null, 
                                        order = 56, 
                                        is_expanded = True, 
                                        content = null, 
                                        id = 56, 
                                        lesson_id = 56, 
                                        created_at = 56, )
                                    ], 
                                attached_files = [
                                    public_api_server_connector_v2.models.attached_file.AttachedFile(
                                        order = 56, 
                                        file_id = 56, 
                                        id = 56, 
                                        lesson_id = 56, 
                                        created_at = 56, )
                                    ], )
                            ], )
                    ],
                content_blocks = [
                    public_api_server_connector_v2.models.course_content_block.CourseContentBlock(
                        block_type = 'text', 
                        order = 56, 
                        is_expanded = True, 
                        content = public_api_server_connector_v2.models.content.Content(
                            link = '', 
                            file_id = '', 
                            audio_id = '', 
                            payload = '', 
                            btn_url = '', 
                            btn_font = '', 
                            btn_size = null, 
                            btn_text = '', 
                            btn_color = '', 
                            btn_target = null, 
                            btn_position = null, 
                            btn_text_color = '', 
                            pdf_id = '', ), 
                        id = 56, 
                        course_id = 56, 
                        created_at = 56, )
                    ],
        )
        """

    def testCourse(self):
        """Test Course"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
