# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ModuleLessonPatch(BaseModel):
    """
    ModuleLessonPatch
    """ # noqa: E501
    submodule_id: Optional[StrictInt] = Field(default=None, description="ID of the submodule this lesson belongs to, if not set, it will be not updated")
    thread_id: Optional[StrictInt] = Field(default=None, description="ID of the community thread this lesson belongs to, if not set, it will be not updated")
    image_id: Optional[StrictStr] = Field(default=None, description="ID of the image associated with the lesson, if not set, it will be not updated")
    order: Optional[StrictInt] = Field(default=None, description="Order of the lesson in the module, if not set, it will be not updated")
    title: Optional[StrictStr] = Field(default=None, description="Title of the lesson, if not set, it will be not updated")
    payload: Optional[StrictStr] = Field(default=None, description="Payload of the lesson, if not set, it will be not updated")
    is_active: Optional[StrictBool] = Field(default=None, description="Whether the lesson is active or not, if not set, it will be not updated")
    is_published: Optional[StrictBool] = Field(default=None, description="Whether the lesson is published or not, if not set, it will be not updated")
    mandatory: Optional[StrictBool] = Field(default=None, description="Whether the lesson is mandatory or not, if not set, it will be not updated")
    __properties: ClassVar[List[str]] = ["submodule_id", "thread_id", "image_id", "order", "title", "payload", "is_active", "is_published", "mandatory"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ModuleLessonPatch from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ModuleLessonPatch from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "submodule_id": obj.get("submodule_id"),
            "thread_id": obj.get("thread_id"),
            "image_id": obj.get("image_id"),
            "order": obj.get("order"),
            "title": obj.get("title"),
            "payload": obj.get("payload"),
            "is_active": obj.get("is_active"),
            "is_published": obj.get("is_published"),
            "mandatory": obj.get("mandatory")
        })
        return _obj


