# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.health_api import HealthApi


class TestHealthApi(unittest.IsolatedAsyncioTestCase):
    """HealthApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = HealthApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_health_health_check(self) -> None:
        """Test case for health_health_check

        Health Check
        """
        pass


if __name__ == '__main__':
    unittest.main()
